@@ -82,12 +82,12 @@ class dyn_obj:
         
         self.quat = R.from_euler(euler_type, pa).as_quat()
         
-        self.non_rot = ref_frame(obj.name+'_non_rot', parent)
+        self.non_rot = ref_frame(obj.name+'_non_rot', parent, init_anim)
         
-        self.pa_axes = ref_frame(obj.name+'_pa', self.non_rot.ob)
+        self.pa_axes = ref_frame(obj.name+'_pa', self.non_rot.ob, init_anim)
         self.pa_axes.static_6DOF(self.quat, None, None, None)
         
-        self.body = ref_frame(obj.name+'_body', self.pa_axes.ob)
+        self.body = ref_frame(obj.name+'_body', self.pa_axes.ob, init_anim)
         
         obj.parent = self.body.ob
         obj.scale = (scale, scale, scale)
@@ -144,7 +144,7 @@ class dyn_vec:
         self.parent = obj
         self.name = name+"_vector"
         
-        self.parent_rf = ref_frame(self.name+"_empty", self.parent)
+        self.parent_rf = ref_frame(self.name+"_empty", self.parent, init_anim)
 
         self.filepath = self.filepath = __file__.replace("__init__.py", "").replace("\\core.py", "")+'\\assets\\objects\\arrow.obj' #"C:/Users/vargh/Documents/GitHub/bpsci/bpsci/assets/objects/arrow.obj" #bpsci.__file__.replace("__init__.py", "")+'\\assets\\objects\\arrow.obj'
 
